@@ -1,13 +1,21 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import packaging
 
 import numpy as np
 
 from numpy.testing import assert_allclose
 import pytest
 from astropy.utils import NumpyRNGContext
+from astropy.utils.exceptions import AstropyDeprecationWarning
 from astropy.nddata import StdDevUncertainty
 from astropy import units as u
 
+try:
+    from astroscrappy import __version__ as asy_version
+except Exception as e:
+    print("Oh no, no working astroscrappy")
+    pytest.skip("skipping astroscrappy tests", allow_module_level=True)
+
 from ccdproc.core import (cosmicray_lacosmic, cosmicray_median,
                     background_deviation_box, background_deviation_filter)
 from ccdproc.tests.pytest_fixtures import ccd_data as ccd_data_func
@@ -16,15 +24,18 @@ from ccdproc.tests.pytest_fixtures import ccd_data as ccd_data_func
 DATA_SCALE = 5.3
 NCRAYS = 30
 
+OLD_ASTROSCRAPPY = (packaging.version.parse(asy_version) <
+                    packaging.version.parse('1.1.0'))
+
 
 def add_cosmicrays(data, scale, threshold, ncrays=NCRAYS):
     size = data.shape[0]
     with NumpyRNGContext(125):
         crrays = np.random.randint(0, size, size=(ncrays, 2))
-        # use (threshold + 1) below to make sure cosmic ray is well above the
+        # use (threshold + 15) below to make sure cosmic ray is well above the
         # threshold no matter what the random number generator returns
         crflux = (10 * scale * np.random.random(NCRAYS) +
-                  (threshold + 5) * scale)
+                  (threshold + 15) * scale)
         for i in range(ncrays):
             y, x = crrays[i]
             data.data[y, x] = crflux[i]
@@ -32,15 +43,15 @@ def add_cosmicrays(data, scale, threshold, ncrays=NCRAYS):
 
 def test_cosmicray_lacosmic():
     ccd_data = ccd_data_func(data_scale=DATA_SCALE)
-    threshold = 5
+    threshold = 10
     add_cosmicrays(ccd_data, DATA_SCALE, threshold, ncrays=NCRAYS)
     noise = DATA_SCALE * np.ones_like(ccd_data.data)
-    data, crarr = cosmicray_lacosmic(ccd_data.data, sigclip=5)
+    data, crarr = cosmicray_lacosmic(ccd_data.data, sigclip=5.9)
 
     # check the number of cosmic rays detected
-    # currently commented out while checking on issues
-    # in astroscrappy
-    # assert crarr.sum() == NCRAYS
+    # Note that to get this to succeed reliably meant tuning
+    # both sigclip and the threshold
+    assert crarr.sum() == NCRAYS
 
 
 def test_cosmicray_lacosmic_ccddata():
@@ -49,12 +60,12 @@ def test_cosmicray_lacosmic_ccddata():
     add_cosmicrays(ccd_data, DATA_SCALE, threshold, ncrays=NCRAYS)
     noise = DATA_SCALE * np.ones_like(ccd_data.data)
     ccd_data.uncertainty = noise
-    nccd_data = cosmicray_lacosmic(ccd_data, sigclip=5)
+    nccd_data = cosmicray_lacosmic(ccd_data, sigclip=5.9)
 
     # check the number of cosmic rays detected
-    # currently commented out while checking on issues
-    # in astroscrappy
-    # assert nccd_data.mask.sum() == NCRAYS
+    # Note that to get this to succeed reliably meant tuning
+    # both sigclip and the threshold
+    assert nccd_data.mask.sum() == NCRAYS
 
 
 def test_cosmicray_lacosmic_check_data():
@@ -180,6 +191,32 @@ def test_cosmicray_lacosmic_warns_on_ccd_in_electrons(recwarn):
     assert "Image unit is electron" in str(recwarn.pop())
 
 
+# The skip can be removed when the oldest supported astroscrappy
+# is 1.1.0 or higher
+@pytest.mark.skipif(OLD_ASTROSCRAPPY,
+                    reason='astroscrappy < 1.1.0 does not support '
+                           'this functionality')
+# The values for inbkg and invar are DELIBERATELY BAD. They are supposed to be
+# arrays, so if detect_cosmics is called with these bad values a ValueError
+# will be raised, which we can check for.
+@pytest.mark.parametrize('new_args', [dict(inbkg=5),
+                                      dict(invar=5),
+                                      dict(inbkg=5, invar=5)])
+def test_cosmicray_lacosmic_invar_inbkg(new_args):
+    # This IS NOT TESTING FUNCTIONALITY it is simply testing
+    # that calling with the new keyword arguments to astroscrappy
+    # 1.1.0 raises no error.
+    ccd_data = ccd_data_func(data_scale=DATA_SCALE)
+    threshold = 5
+    add_cosmicrays(ccd_data, DATA_SCALE, threshold, ncrays=NCRAYS)
+    noise = DATA_SCALE * np.ones_like(ccd_data.data)
+    ccd_data.uncertainty = noise
+
+    with pytest.raises(TypeError):
+        nccd_data = cosmicray_lacosmic(ccd_data, sigclip=5.9,
+                                       **new_args)
+
+
 def test_cosmicray_median_check_data():
     with pytest.raises(TypeError):
         ndata, crarr = cosmicray_median(10, thresh=5, mbox=11,
@@ -294,3 +331,64 @@ def test_background_deviation_filter_fail():
         cd = np.random.normal(loc=0, size=(100, 100), scale=scale)
     with pytest.raises(ValueError):
         background_deviation_filter(cd, 0.5)
+
+
+# This test can be removed in ccdproc 3.0 when support for old
+# astroscrappy is removed.
+def test_cosmicray_lacosmic_pssl_deprecation_warning():
+    ccd_data = ccd_data_func(data_scale=DATA_SCALE)
+    with pytest.warns(AstropyDeprecationWarning):
+        cosmicray_lacosmic(ccd_data, pssl=1.0)
+
+
+# Remaining tests can be removed when the oldest supported version
+# of astroscrappy is 1.1.0 or higher.
+@pytest.mark.skipif(not OLD_ASTROSCRAPPY,
+                    reason='Should succeed for new astroscrappy')
+@pytest.mark.parametrize('bad_args', [dict(inbkg=5),
+                                      dict(invar=5),
+                                      dict(inbkg=5, invar=5)])
+def test_error_raised_lacosmic_old_interface_new_args(bad_args):
+    ccd_data = ccd_data_func(data_scale=DATA_SCALE)
+    with pytest.raises(TypeError) as err:
+        cosmicray_lacosmic(ccd_data, **bad_args)
+
+    check_message = [k in str(err) for k in bad_args.keys()]
+    assert all(check_message)
+
+
+@pytest.mark.skipif(OLD_ASTROSCRAPPY,
+                    reason='Test is of new interface compatibility layer')
+def test_cosmicray_lacosmic_pssl_and_inbkg_fails():
+    ccd_data = ccd_data_func(data_scale=DATA_SCALE)
+    with pytest.raises(ValueError) as err:
+        # An error should be raised if both pssl and inbkg are provided
+        with pytest.warns(AstropyDeprecationWarning):
+            # The deprecation warning is expected and should be captured
+            cosmicray_lacosmic(ccd_data, pssl=3, inbkg=ccd_data.data)
+
+    assert 'pssl and inbkg' in str(err)
+
+
+@pytest.mark.skipif(OLD_ASTROSCRAPPY,
+                    reason='Test is of new interface compatibility layer')
+def test_cosmicray_lacosmic_pssl_does_not_fail():
+    # This test is a copy/paste of test_cosmicray_lacosmic_ccddata
+    # except with pssl=0.0001 as an argument. Subtracting nearly zero from
+    # the background should have no effect. The test is really
+    # to make sure that passing in pssl does not lead to an error
+    # since the new interface does not include pssl.
+    ccd_data = ccd_data_func(data_scale=DATA_SCALE)
+    threshold = 5
+    add_cosmicrays(ccd_data, DATA_SCALE, threshold, ncrays=NCRAYS)
+    noise = DATA_SCALE * np.ones_like(ccd_data.data)
+    ccd_data.uncertainty = noise
+    with pytest.warns(AstropyDeprecationWarning):
+        # The deprecation warning is expected and should be captured
+        nccd_data = cosmicray_lacosmic(ccd_data, sigclip=5.9,
+                                       pssl=0.0001)
+
+    # check the number of cosmic rays detected
+    # Note that to get this to succeed reliably meant tuning
+    # both sigclip and the threshold
+    assert nccd_data.mask.sum() == NCRAYS
